# mhyy.py

![LICENSE](https://img.shields.io/github/license/GuangChen2333/mhyy.py?style=flat-square)
![Downloads](https://img.shields.io/pypi/dm/mhyy.py?style=flat-square)
![PyP](https://img.shields.io/pypi/v/mhyy.py?style=flat-square)
![Python](https://img.shields.io/pypi/pyversions/mhyy.py?style=flat-square)
![STARS](https://img.shields.io/github/stars/GuangChen2333/mhyy.py?style=flat-square)

Python 米哈云游（云·原神、云·星穷铁道）签到功能与相关方法的API

## 安装

- 从 `PyPi` 安装 `mhyy.py`

```shell
pip install mhyy.py
```

## 文档

访问 <https://mhyy.mooneze.org/> 获取更多细节

## 关于

欢迎协作本项目，如果你有任何意见或想法，请提出 Issue 或 Pull Request。

如果你喜欢此项目，请给该仓库点一个 Star。